@@ -2,4 +2,4 @@
 
 python3 -m pip install --upgrade twine
 
-python3 -m twine upload --repository pypi dist/*
\ No newline at end of file
+python3 -m twine upload --repository bashckup dist/*
\ No newline at end of file
